@@ -69,6 +69,7 @@ TRANSACTION_STYLE_VALUES = ("endpoint", "url")
 
 class StarletteIntegration(Integration):
     identifier = "starlette"
+    origin = f"auto.http.{identifier}"
 
     transaction_style = ""
 
@@ -123,7 +124,9 @@ def _enable_span_for_middleware(middleware_class):
             )
 
         with sentry_sdk.start_span(
-            op=OP.MIDDLEWARE_STARLETTE, description=middleware_name
+            op=OP.MIDDLEWARE_STARLETTE,
+            description=middleware_name,
+            origin=StarletteIntegration.origin,
         ) as middleware_span:
             middleware_span.set_tag("starlette.middleware_name", middleware_name)
 
@@ -133,6 +136,7 @@ def _enable_span_for_middleware(middleware_class):
                 with sentry_sdk.start_span(
                     op=OP.MIDDLEWARE_STARLETTE_RECEIVE,
                     description=getattr(receive, "__qualname__", str(receive)),
+                    origin=StarletteIntegration.origin,
                 ) as span:
                     span.set_tag("starlette.middleware_name", middleware_name)
                     return await receive(*args, **kwargs)
@@ -147,6 +151,7 @@ def _enable_span_for_middleware(middleware_class):
                 with sentry_sdk.start_span(
                     op=OP.MIDDLEWARE_STARLETTE_SEND,
                     description=getattr(send, "__qualname__", str(send)),
+                    origin=StarletteIntegration.origin,
                 ) as span:
                     span.set_tag("starlette.middleware_name", middleware_name)
                     return await send(*args, **kwargs)
@@ -356,6 +361,7 @@ def patch_asgi_app():
             lambda *a, **kw: old_app(self, *a, **kw),
             mechanism_type=StarletteIntegration.identifier,
             transaction_style=integration.transaction_style,
+            span_origin=StarletteIntegration.origin,
         )
 
         middleware.__call__ = middleware._run_asgi3
